==> celestine-0.4.0-py3-none-any.whl: celestine/language/pl.py <==
"""pl Polish polski"""
APPLICATION_TITLE = "Przeglądarka obrazów Celestine"
ARGUMENT_APPLICATION_DESCRIPTION = "Twoje wartości programu idą tutaj. \
Yay."
ARGUMENT_APPLICATION_HELP = "Wybierz aplikację do uruchomienia."
ARGUMENT_APPLICATION_TITLE = "Aplikacja"
ARGUMENT_CUSTOMIZATION_DESCRIPTION = "\
Celestine spróbuje odgadnąć najlepsze ustawienia do użycia. \
Zamiast tego możesz poprosić o użycie tych wartości."
ARGUMENT_CUSTOMIZATION_TITLE = "Dostosowywania"
ARGUMENT_HELP_HELP = "Wyświetla ten ekran pomocy."
ARGUMENT_INFORMATION_DESCRIPTION = "\
Włączenie ich spowoduje zakończenie programu do wyświetlania informacji."
ARGUMENT_INFORMATION_TITLE = "Informacja"
ARGUMENT_INTERFACE_HELP = "Którego GUI chcesz użyć?"
ARGUMENT_LANGUAGE_HELP = "W UE obowiązują 24 języki urzędowe: \
angielski, bułgarski, chorwacki, czeski, duński, estoński, fiński, \
francuski, grecki, hiszpański, irlandzki, litewski, łotewski, \
maltański, niderlandzki, niemiecki, polski, portugalski, rumuński, \
słowacki, słoweński, szwedzki, węgierski i włoski."
ARGUMENT_MODIFICATION_DESCRIPTION = "Konfigurowanie flag"
ARGUMENT_MODIFICATION_TITLE = "Modyfikacji"
ARGUMENT_PARSER_ARGUMENT = "argument"
ARGUMENT_PARSER_CHOICE = "Nieprawidłowy wybór"
ARGUMENT_PARSER_CHOOSE = "wybierz jedną z"
ARGUMENT_PARSER_ERROR = "błąd"
ARGUMENT_PARSER_USAGE = "zwyczaj"
ARGUMENT_PYTHON_HELP = "Wybierz używaną wersję języka Python."
ARGUMENT_VERSION_HELP = "Pokazuje bieżącą wersję."
CURSES_EXIT = "Naciśnij ESC, aby wyjść."
DEMO_MAIN_NEXT = "Przejdź do strony drugiej."
DEMO_MAIN_PAST = "Przejdź do strony pierwszej."
DEMO_MAIN_TITLE = "Strona główna."
DEMO_ONE_NEXT = "Przejdź do strony drugiej."
DEMO_ONE_PAST = "Przejdź do strony głównej."
DEMO_ONE_TITLE = "Strona pierwsza."
DEMO_TWO_NEXT = "Przejdź do strony głównej."
DEMO_TWO_PAST = "Przejdź do strony pierwszej."
DEMO_TWO_TITLE = "Strona druga."
LANGUAGE = "W UE obowiązują 24 języki urzędowe: angielski, bułgarski, \
chorwacki, czeski, duński, estoński, fiński, francuski, grecki, \
hiszpański, irlandzki, litewski, łotewski, maltański, niderlandzki, \
niemiecki, polski, portugalski, rumuński, słowacki, słoweński, \
szwedzki, węgierski i włoski."
LANGUAGE_NAME_ENGLISH = "Polish"
LANGUAGE_NAME_NATIVE = "polski"
LANGUAGE_TAG_AZURE = "pl"
LANGUAGE_TAG_ISO = "pl"
TRANSLATOR_FILE_ERROR_OVERFLOW = "Zrobiliśmy przepełnienie."
TRANSLATOR_SESSION_KEY = "\
Klucz usługi Translator z witryny Azure Portal. \
Your Translator service key from the Azure portal."
TRANSLATOR_SESSION_REGION = "Region, w którym utworzono zasób."
TRANSLATOR_SESSION_URL = "Lokalizacja usługi tłumaczeniowej."
VIEWER_SESSION_DIRECTORY = "Ścieżka do katalogu zawierającego obrazy."

==> celestine-2024.6.9-py3-none-any.whl: celestine/language/pl.py <==
"""Polish polski pl."""

APPLICATION_TITLE = "Przeglądarka obrazów Celestine"

ARGUMENT_APPLICATION_DESCRIPTION = "\
Twoje wartości programu idą tutaj. Yay."

ARGUMENT_APPLICATION_HELP = "Wybierz aplikację do uruchomienia."

ARGUMENT_APPLICATION_TITLE = "Aplikacja"

ARGUMENT_CUSTOMIZATION_DESCRIPTION = "\
Celestine spróbuje odgadnąć najlepsze ustawienia do użycia. \
Zamiast tego możesz poprosić o użycie tych wartości."

ARGUMENT_CUSTOMIZATION_TITLE = "Dostosowywania"

ARGUMENT_HELP_HELP = "Wyświetla ten ekran pomocy."

ARGUMENT_INFORMATION_DESCRIPTION = "\
Włączenie ich spowoduje zakończenie programu do wyświetlania \
informacji."

ARGUMENT_INFORMATION_TITLE = "Informacja"

ARGUMENT_INTERFACE_HELP = "Którego GUI chcesz użyć?"

ARGUMENT_LANGUAGE_HELP = "\
W UE obowiązują 24 języki urzędowe: \
angielski, bułgarski, chorwacki, czeski, duński, estoński, fiński, \
francuski, grecki, hiszpański, irlandzki, litewski, łotewski, \
maltański, niderlandzki, niemiecki, polski, portugalski, rumuński, \
słowacki, słoweński, szwedzki, węgierski i włoski."

ARGUMENT_MODIFICATION_DESCRIPTION = "Konfigurowanie flag"

ARGUMENT_MODIFICATION_TITLE = "Modyfikacji"

ARGUMENT_PARSER_ARGUMENT = "argument"

ARGUMENT_PARSER_CHOICE = "Nieprawidłowy wybór"

ARGUMENT_PARSER_CHOOSE = "wybierz jedną z"

ARGUMENT_PARSER_ERROR = "błąd"

ARGUMENT_PARSER_USAGE = "zwyczaj"

ARGUMENT_PYTHON_HELP = "Wybierz używaną wersję języka Python."

ARGUMENT_VERSION_HELP = "Pokazuje bieżącą wersję."

CLEAN_MAIN_CLEAN = "Sformatuj wszystkie pliki kodu Pythona."

CLEAN_MAIN_LICENCE = "Wyczyść pliki licencji."

CLEAN_MAIN_TITLE = "Skrypty przygotowujące projekt do publikacji."

CLEAN_MAIN_VERSION = "Numer wersji aktualizacji."

CURSES_EXIT = "Naciśnij ESC, aby wyjść."

DEMO_COW_TALK = "Jestem gadającą krową."

DEMO_ZERO_ACTION = "Pozdrów krowę."

DEMO_MAIN_NEXT = "Przejdź do strony drugiej."

DEMO_MAIN_PAST = "Przejdź do strony pierwszej."

DEMO_ZERO_SAY = "Witaj człowieku."

DEMO_ZERO_TITLE = "Strona główna."

DEMO_ONE_ACTION = "Nakarm krowę."

DEMO_ONE_NEXT = "Przejdź do strony drugiej."

DEMO_ONE_PAST = "Przejdź do strony głównej."

DEMO_ONE_SAY = "Jedzenie smakuje dobrze."

DEMO_ONE_TITLE = "Strona pierwsza."

DEMO_TWO_ACTION = "Pomachaj do krowy."

DEMO_TWO_NEXT = "Przejdź do strony głównej."

DEMO_TWO_PAST = "Przejdź do strony pierwszej."

DEMO_TWO_SAY = "Żegnaj człowieku."

DEMO_TWO_TITLE = "Strona druga."

LANGUAGE = "\
W UE obowiązują 24 języki urzędowe: \
angielski, bułgarski, chorwacki, czeski, duński, estoński, fiński, \
francuski, grecki, hiszpański, irlandzki, litewski, łotewski, \
maltański, niderlandzki, niemiecki, polski, portugalski, rumuński, \
słowacki, słoweński, szwedzki, węgierski i włoski."

LANGUAGE_NAME_ENGLISH = "Angielski"

LANGUAGE_NAME_NATIVE = "Angielski"

LANGUAGE_TAG_AZURE = "En"

LANGUAGE_TAG_ISO = "En"

SCAN_MAIN_BUTTON = "Ten przycisk nic nie robi."

SCAN_MAIN_TITLE = "Przyszły projekt skanowania bezpieczeństwa"

SESSION_PARSER_CHOICE = "Nieprawidłowy wybór"

SESSION_PARSER_CHOOSE = "wybierz jedną z"

SESSION_PARSER_ERROR = "błąd"

SESSION_PARSER_UNRECOGNIZED = "Nierozpoznane argumenty"

SESSION_PARSER_USAGE = "zwyczaj"

TRANSLATOR_FILE_ERROR_OVERFLOW = "Zrobiliśmy przepełnienie."

TRANSLATOR_MAIN_BUTTON = "Tłumaczenie plików"

TRANSLATOR_REPORT_BUTTON = "Raport dotyczący plików."

TRANSLATOR_SESSION_KEY = "\
Klucz usługi Translator z witryny Azure Portal. \
Your Translator service key from the Azure portal."

TRANSLATOR_SESSION_REGION = "Region, w którym utworzono zasób."

TRANSLATOR_SESSION_URL = "Lokalizacja usługi tłumaczeniowej."

VIEWER_MAIN_BUTTON = "Załaduj obrazy do katalogu."

VIEWER_SESSION_DIRECTORY = "Ścieżka do katalogu zawierającego obrazy."

name = "En"

########################################################################

LANGUAGE = "\
W UE obowiązują 24 języki urzędowe: \
angielski, bułgarski, chorwacki, czeski, duński, estoński, fiński, \
francuski, grecki, hiszpański, irlandzki, litewski, łotewski, \
maltański, niderlandzki, niemiecki, polski, portugalski, rumuński, \
słowacki, słoweński, szwedzki, węgierski i włoski."

LANGUAGE_NAME_ENGLISH = "Polish"

LANGUAGE_NAME_NATIVE = "polski"

LANGUAGE_TAG_AZURE = "pl"

LANGUAGE_TAG_ISO = "pl"
